==> blancoNLpackGenerator-0.1.7-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorDiffResultDetailProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorDiffResultDetailProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorDiffResultDetailProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourceleft]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO()B
     */
    private String fSourceleft;

    /**
     * tB[h [sourceright]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO(E)B
     */
    private String fSourceright;

    /**
     * tB[h [targetdiff]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃOt@CB
     */
    private String fTargetdiff;

    /**
     * tB[h [reportequal]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * vs񍐂邩ǂBʏ ͕svƍlĂ܂B
     */
    private boolean fReportequal = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourceleft]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO()B
     *
     * @param argSourceleft tB[h[sourceleft]Ɋi[l
     */
    public void setSourceleft(final String argSourceleft) {
        fSourceleft = argSourceleft;
    }

    /**
     * tB[h[sourceleft]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO()B
     *
     * @return tB[h[sourceleft]Ɋi[Ăl
     */
    public String getSourceleft() {
        return fSourceleft;
    }

    /**
     * tB[h [sourceright]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO(E)B
     *
     * @param argSourceright tB[h[sourceright]Ɋi[l
     */
    public void setSourceright(final String argSourceright) {
        fSourceright = argSourceright;
    }

    /**
     * tB[h[sourceright]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̖͂|󌋉ʃO(E)B
     *
     * @return tB[h[sourceright]Ɋi[Ăl
     */
    public String getSourceright() {
        return fSourceright;
    }

    /**
     * tB[h [targetdiff]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃOt@CB
     *
     * @param argTargetdiff tB[h[targetdiff]Ɋi[l
     */
    public void setTargetdiff(final String argTargetdiff) {
        fTargetdiff = argTargetdiff;
    }

    /**
     * tB[h[targetdiff]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃOt@CB
     *
     * @return tB[h[targetdiff]Ɋi[Ăl
     */
    public String getTargetdiff() {
        return fTargetdiff;
    }

    /**
     * tB[h [reportequal]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * vs񍐂邩ǂBʏ ͕svƍlĂ܂B
     *
     * @param argReportequal tB[h[reportequal]Ɋi[l
     */
    public void setReportequal(final boolean argReportequal) {
        fReportequal = argReportequal;
    }

    /**
     * tB[h[reportequal]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * vs񍐂邩ǂBʏ ͕svƍlĂ܂B
     *
     * @return tB[h[reportequal]Ɋi[Ăl
     */
    public boolean getReportequal() {
        return fReportequal;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorDiffResultDetailProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourceleft=" + fSourceleft);
        buf.append(",sourceright=" + fSourceright);
        buf.append(",targetdiff=" + fTargetdiff);
        buf.append(",reportequal=" + fReportequal);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.21-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorDiffResultDetailProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorDiffResultDetailProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorDiffResultDetailProcessInput {
    /**
     * verbose[hœ삳邩ǂB
     *
     * tB[h: [verbose]B
     * ftHg: [false]B
     */
    private boolean fVerbose = false;

    /**
     * ̖͂|󌋉ʃO()B
     *
     * tB[h: [sourceleft]B
     */
    private String fSourceleft;

    /**
     * ̖͂|󌋉ʃO(E)B
     *
     * tB[h: [sourceright]B
     */
    private String fSourceright;

    /**
     * o̖͂|󌋉ʃOt@CB
     *
     * tB[h: [targetdiff]B
     */
    private String fTargetdiff;

    /**
     * vs񍐂邩ǂBʏ ͕svƍlĂ܂B
     *
     * tB[h: [reportequal]B
     * ftHg: [false]B
     */
    private boolean fReportequal = false;

    /**
     * tB[h [verbose] ̒lݒ肵܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     *
     * @param argVerbose tB[h[verbose]ɐݒ肷lB
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h [verbose] ̒l擾܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     * ftHg: [false]B
     *
     * @return tB[h[verbose]擾lB
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourceleft] ̒lݒ肵܂B
     *
     * tB[h̐: [̖͂|󌋉ʃO()B]B
     *
     * @param argSourceleft tB[h[sourceleft]ɐݒ肷lB
     */
    public void setSourceleft(final String argSourceleft) {
        fSourceleft = argSourceleft;
    }

    /**
     * tB[h [sourceleft] ̒l擾܂B
     *
     * tB[h̐: [̖͂|󌋉ʃO()B]B
     *
     * @return tB[h[sourceleft]擾lB
     */
    public String getSourceleft() {
        return fSourceleft;
    }

    /**
     * tB[h [sourceright] ̒lݒ肵܂B
     *
     * tB[h̐: [̖͂|󌋉ʃO(E)B]B
     *
     * @param argSourceright tB[h[sourceright]ɐݒ肷lB
     */
    public void setSourceright(final String argSourceright) {
        fSourceright = argSourceright;
    }

    /**
     * tB[h [sourceright] ̒l擾܂B
     *
     * tB[h̐: [̖͂|󌋉ʃO(E)B]B
     *
     * @return tB[h[sourceright]擾lB
     */
    public String getSourceright() {
        return fSourceright;
    }

    /**
     * tB[h [targetdiff] ̒lݒ肵܂B
     *
     * tB[h̐: [o̖͂|󌋉ʃOt@CB]B
     *
     * @param argTargetdiff tB[h[targetdiff]ɐݒ肷lB
     */
    public void setTargetdiff(final String argTargetdiff) {
        fTargetdiff = argTargetdiff;
    }

    /**
     * tB[h [targetdiff] ̒l擾܂B
     *
     * tB[h̐: [o̖͂|󌋉ʃOt@CB]B
     *
     * @return tB[h[targetdiff]擾lB
     */
    public String getTargetdiff() {
        return fTargetdiff;
    }

    /**
     * tB[h [reportequal] ̒lݒ肵܂B
     *
     * tB[h̐: [vs񍐂邩ǂBʏ ͕svƍlĂ܂B]B
     *
     * @param argReportequal tB[h[reportequal]ɐݒ肷lB
     */
    public void setReportequal(final boolean argReportequal) {
        fReportequal = argReportequal;
    }

    /**
     * tB[h [reportequal] ̒l擾܂B
     *
     * tB[h̐: [vs񍐂邩ǂBʏ ͕svƍlĂ܂B]B
     * ftHg: [false]B
     *
     * @return tB[h[reportequal]擾lB
     */
    public boolean getReportequal() {
        return fReportequal;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorDiffResultDetailProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourceleft=" + fSourceleft);
        buf.append(",sourceright=" + fSourceright);
        buf.append(",targetdiff=" + fTargetdiff);
        buf.append(",reportequal=" + fReportequal);
        buf.append("]");
        return buf.toString();
    }
}
